@@ -7,6 +7,7 @@ import typer
 import tiktoken
 import warnings
 from transformers import AutoTokenizer
+import importlib.metadata
 
 from .config import BenchmarkConfig
 from .scoring import calculate_self_attestation_scores, calculate_self_attestation_scores_bottom_up
@@ -30,12 +31,20 @@ class FinesseEvaluator:
 
     def raw_run(self) -> Dict[str, Any]:
         """Finesse 벤치마크 실행: Stratified CSAT with Single-Pass Conveyor Belt (Raw mode - embeddings only)"""
-        # Load dataset without any version parameter to use default
+        # Load dataset with specific revision for declarative reproducibility
         dataset = load_dataset(
             path=self.config.dataset.path,
-            split=self.config.dataset.split
+            split=self.config.dataset.split,
+            revision=self.config.dataset.commit_hash
         )
 
+        # Capture dataset metadata from config declaration
+        dataset_metadata = {
+            'path': self.config.dataset.path,
+            'split': self.config.dataset.split,
+            'commit_hash': self.config.dataset.commit_hash
+        }
+
         # Shuffle dataset deterministically for reproducibility
         if self.config.seed is not None:
             dataset = dataset.shuffle(seed=self.config.seed)
@@ -111,7 +120,6 @@ class FinesseEvaluator:
                                 break
                         
 
-                    
                     except (StopIteration, KeyError):
                         # 이터레이터가 끝나면 다시 시작
                         iterator = iter(dataset)
@@ -162,8 +170,23 @@ class FinesseEvaluator:
                 'num_synth_steps': target_length
             }
 
+        # Add metadata for provenance
+        try:
+            version = importlib.metadata.version('finesse-benchmark')
+            package_metadata = {'finesse-benchmark': version}
+        except importlib.metadata.PackageNotFoundError:
+            package_metadata = {'finesse-benchmark': 'unknown'}
+        except Exception as e:
+            package_metadata = {'finesse-benchmark': f'error: {str(e)}'}
+
+        metadata = {
+            'package_versions': package_metadata,
+            'dataset': dataset_metadata
+        }
+
         return {
             'config': self.config.model_dump(),
+            'metadata': metadata,
             'raw_results': {
                 'length_results': length_results
             }
